==> jc-1.4.0.tar.gz: gnu/java/security/provider/DSAKeyPairGenerator.h <==
// public class gnu.java.security.provider.DSAKeyPairGenerator

// class file dependencies
// @dep_class 3632d111e7aa48f5 gnu_java_security_provider_DSAKeyPairGenerator
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 688f793da35179d1 java_security_KeyPairGeneratorSpi

// header file dependencies
// @dep_header java_security_KeyPairGeneratorSpi

#include "java/security/KeyPairGeneratorSpi.h"

#ifndef _JC_gnu_java_security_provider_DSAKeyPairGenerator_H_
#define _JC_gnu_java_security_provider_DSAKeyPairGenerator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_math_BigInteger$object;
struct _jc_java_security_KeyPair$object;
struct _jc_java_security_SecureRandom$object;
struct _jc_java_security_interfaces_DSAParams$object;
struct _jc_java_security_spec_AlgorithmParameterSpec$object;

// Typedefs
typedef struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$sub_refs	_jc_gnu_java_security_provider_DSAKeyPairGenerator$sub_refs;
typedef struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$sub_nonrefs	_jc_gnu_java_security_provider_DSAKeyPairGenerator$sub_nonrefs;
typedef struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$refs	_jc_gnu_java_security_provider_DSAKeyPairGenerator$refs;
typedef struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$nonrefs	_jc_gnu_java_security_provider_DSAKeyPairGenerator$nonrefs;
typedef struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$object	_jc_gnu_java_security_provider_DSAKeyPairGenerator$object;

typedef struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$fields_struct	_jc_gnu_java_security_provider_DSAKeyPairGenerator$fields_struct;
typedef const struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$vmethods	_jc_gnu_java_security_provider_DSAKeyPairGenerator$vmethods;
typedef const struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$vtable	_jc_gnu_java_security_provider_DSAKeyPairGenerator$vtable;
typedef const struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$vtype	_jc_gnu_java_security_provider_DSAKeyPairGenerator$vtype;

// Class fields structure
struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24security__24spec__24DSAParameterSpec;
};
extern _jc_gnu_java_security_provider_DSAKeyPairGenerator$fields_struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$class_fields;

// Constructors
extern void _jc_gnu_java_security_provider_DSAKeyPairGenerator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$object *);

// Virtual methods
extern struct _jc_java_security_KeyPair$object *_jc_gnu_java_security_provider_DSAKeyPairGenerator$method$generateKeyPair$e0a9411286c772d9(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$object *);
extern jboolean _jc_gnu_java_security_provider_DSAKeyPairGenerator$method$getDefaults$99b7305fb9f2001b(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$object *);
extern void _jc_gnu_java_security_provider_DSAKeyPairGenerator$method$initialize$8377579c986315b7(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$object *, jint, struct _jc_java_security_SecureRandom$object *);
extern void _jc_gnu_java_security_provider_DSAKeyPairGenerator$method$initialize$6a0c329ca5dceb6f(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$object *, jint, jboolean, struct _jc_java_security_SecureRandom$object *);
extern void _jc_gnu_java_security_provider_DSAKeyPairGenerator$method$initialize$575e50e0142c97af(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$object *, struct _jc_object *, struct _jc_java_security_SecureRandom$object *);
extern void _jc_gnu_java_security_provider_DSAKeyPairGenerator$method$initialize$a73c0ba67824ad04(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$object *, struct _jc_object *, struct _jc_java_security_SecureRandom$object *);
extern void _jc_gnu_java_security_provider_DSAKeyPairGenerator$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_provider_DSAKeyPairGenerator$method_info$generateKeyPair$e0a9411286c772d9;
extern _jc_method _jc_gnu_java_security_provider_DSAKeyPairGenerator$method_info$getDefaults$99b7305fb9f2001b;
extern _jc_method _jc_gnu_java_security_provider_DSAKeyPairGenerator$method_info$initialize$8377579c986315b7;
extern _jc_method _jc_gnu_java_security_provider_DSAKeyPairGenerator$method_info$initialize$6a0c329ca5dceb6f;
extern _jc_method _jc_gnu_java_security_provider_DSAKeyPairGenerator$method_info$initialize$575e50e0142c97af;
extern _jc_method _jc_gnu_java_security_provider_DSAKeyPairGenerator$method_info$initialize$a73c0ba67824ad04;
extern _jc_method _jc_gnu_java_security_provider_DSAKeyPairGenerator$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_provider_DSAKeyPairGenerator$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$vmethods {
	struct _jc_java_security_KeyPair$object	*(*generateKeyPair$e0a9411286c772d9)(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$object *);
	jboolean	(*getDefaults$99b7305fb9f2001b)(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$object *);
	void	(*initialize$8377579c986315b7)(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$object *, jint, struct _jc_java_security_SecureRandom$object *);
	void	(*initialize$6a0c329ca5dceb6f)(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$object *, jint, jboolean, struct _jc_java_security_SecureRandom$object *);
	void	(*initialize$575e50e0142c97af)(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$object *, struct _jc_object *, struct _jc_java_security_SecureRandom$object *);
	void	(*initialize$a73c0ba67824ad04)(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$object *, struct _jc_object *, struct _jc_java_security_SecureRandom$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$object *);
};

// Vtable
struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_KeyPairGeneratorSpi$vmethods	java_security_KeyPairGeneratorSpi;
	_jc_gnu_java_security_provider_DSAKeyPairGenerator$vmethods	gnu_java_security_provider_DSAKeyPairGenerator;
};

// Vtype
struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$vtype {
	_jc_type			type;
	_jc_gnu_java_security_provider_DSAKeyPairGenerator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$sub_refs {
	struct _jc_java_security_SecureRandom$object	*random;
	struct _jc_java_math_BigInteger$object	*q;
	struct _jc_java_math_BigInteger$object	*p;
	struct _jc_java_math_BigInteger$object	*g;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$refs {
    _jc_gnu_java_security_provider_DSAKeyPairGenerator$sub_refs	gnu_java_security_provider_DSAKeyPairGenerator;
    _jc_java_security_KeyPairGeneratorSpi$sub_refs	java_security_KeyPairGeneratorSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$sub_nonrefs {
	jint	keysize;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_KeyPairGeneratorSpi$sub_nonrefs	java_security_KeyPairGeneratorSpi;
    _jc_gnu_java_security_provider_DSAKeyPairGenerator$sub_nonrefs	gnu_java_security_provider_DSAKeyPairGenerator;
};

// Object instance structure
struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$object {
	_jc_gnu_java_security_provider_DSAKeyPairGenerator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_provider_DSAKeyPairGenerator$vtype	*vtype;
	_jc_gnu_java_security_provider_DSAKeyPairGenerator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_provider_DSAKeyPairGenerator$vtype _jc_gnu_java_security_provider_DSAKeyPairGenerator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_provider_DSAKeyPairGenerator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_provider_DSAKeyPairGenerator$class_object;

#endif	/* _JC_gnu_java_security_provider_DSAKeyPairGenerator_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/provider/DSAKeyPairGenerator.h <==
// public class gnu.java.security.provider.DSAKeyPairGenerator

// class file dependencies
// @dep_class 3632d111e7aa48f5 gnu_java_security_provider_DSAKeyPairGenerator
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 688f793da35179d1 java_security_KeyPairGeneratorSpi

// header file dependencies
// @dep_header java_security_KeyPairGeneratorSpi

#include "java/security/KeyPairGeneratorSpi.h"

#ifndef _JC_gnu_java_security_provider_DSAKeyPairGenerator_H_
#define _JC_gnu_java_security_provider_DSAKeyPairGenerator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_math_BigInteger$object;
struct _jc_java_security_KeyPair$object;
struct _jc_java_security_SecureRandom$object;
struct _jc_java_security_interfaces_DSAParams$object;
struct _jc_java_security_spec_AlgorithmParameterSpec$object;

// Typedefs
typedef struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$sub_refs	_jc_gnu_java_security_provider_DSAKeyPairGenerator$sub_refs;
typedef struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$sub_nonrefs	_jc_gnu_java_security_provider_DSAKeyPairGenerator$sub_nonrefs;
typedef struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$refs	_jc_gnu_java_security_provider_DSAKeyPairGenerator$refs;
typedef struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$nonrefs	_jc_gnu_java_security_provider_DSAKeyPairGenerator$nonrefs;
typedef struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$object	_jc_gnu_java_security_provider_DSAKeyPairGenerator$object;

typedef struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$fields_struct	_jc_gnu_java_security_provider_DSAKeyPairGenerator$fields_struct;
typedef const struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$vmethods	_jc_gnu_java_security_provider_DSAKeyPairGenerator$vmethods;
typedef const struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$vtable	_jc_gnu_java_security_provider_DSAKeyPairGenerator$vtable;
typedef const struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$vtype	_jc_gnu_java_security_provider_DSAKeyPairGenerator$vtype;

// Class fields structure
struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24security__24spec__24DSAParameterSpec;
};
extern _jc_gnu_java_security_provider_DSAKeyPairGenerator$fields_struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$class_fields;

// Constructors
extern void _jc_gnu_java_security_provider_DSAKeyPairGenerator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_security_KeyPair$object *_jc_gnu_java_security_provider_DSAKeyPairGenerator$method$generateKeyPair$e0a9411286c772d9(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_java_security_provider_DSAKeyPairGenerator$method$getDefaults$99b7305fb9f2001b(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_provider_DSAKeyPairGenerator$method$initialize$8377579c986315b7(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$object *, jint, struct _jc_java_security_SecureRandom$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_provider_DSAKeyPairGenerator$method$initialize$6a0c329ca5dceb6f(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$object *, jint, jboolean, struct _jc_java_security_SecureRandom$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_provider_DSAKeyPairGenerator$method$initialize$575e50e0142c97af(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$object *, struct _jc_object *, struct _jc_java_security_SecureRandom$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_provider_DSAKeyPairGenerator$method$initialize$a73c0ba67824ad04(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$object *, struct _jc_object *, struct _jc_java_security_SecureRandom$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_provider_DSAKeyPairGenerator$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_provider_DSAKeyPairGenerator$method_info$generateKeyPair$e0a9411286c772d9;
extern _jc_method _jc_gnu_java_security_provider_DSAKeyPairGenerator$method_info$getDefaults$99b7305fb9f2001b;
extern _jc_method _jc_gnu_java_security_provider_DSAKeyPairGenerator$method_info$initialize$8377579c986315b7;
extern _jc_method _jc_gnu_java_security_provider_DSAKeyPairGenerator$method_info$initialize$6a0c329ca5dceb6f;
extern _jc_method _jc_gnu_java_security_provider_DSAKeyPairGenerator$method_info$initialize$575e50e0142c97af;
extern _jc_method _jc_gnu_java_security_provider_DSAKeyPairGenerator$method_info$initialize$a73c0ba67824ad04;
extern _jc_method _jc_gnu_java_security_provider_DSAKeyPairGenerator$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_provider_DSAKeyPairGenerator$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$vmethods {
	struct _jc_java_security_KeyPair$object	*(*generateKeyPair$e0a9411286c772d9)(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$object *) _JC_JCNI_ATTR;
	jboolean	(*getDefaults$99b7305fb9f2001b)(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$object *) _JC_JCNI_ATTR;
	void	(*initialize$8377579c986315b7)(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$object *, jint, struct _jc_java_security_SecureRandom$object *) _JC_JCNI_ATTR;
	void	(*initialize$6a0c329ca5dceb6f)(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$object *, jint, jboolean, struct _jc_java_security_SecureRandom$object *) _JC_JCNI_ATTR;
	void	(*initialize$575e50e0142c97af)(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$object *, struct _jc_object *, struct _jc_java_security_SecureRandom$object *) _JC_JCNI_ATTR;
	void	(*initialize$a73c0ba67824ad04)(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$object *, struct _jc_object *, struct _jc_java_security_SecureRandom$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_KeyPairGeneratorSpi$vmethods	java_security_KeyPairGeneratorSpi;
	_jc_gnu_java_security_provider_DSAKeyPairGenerator$vmethods	gnu_java_security_provider_DSAKeyPairGenerator;
};

// Vtype
struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$vtype {
	_jc_type			type;
	_jc_gnu_java_security_provider_DSAKeyPairGenerator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$sub_refs {
	struct _jc_java_security_SecureRandom$object	*random;
	struct _jc_java_math_BigInteger$object	*q;
	struct _jc_java_math_BigInteger$object	*p;
	struct _jc_java_math_BigInteger$object	*g;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$refs {
    _jc_gnu_java_security_provider_DSAKeyPairGenerator$sub_refs	gnu_java_security_provider_DSAKeyPairGenerator;
    _jc_java_security_KeyPairGeneratorSpi$sub_refs	java_security_KeyPairGeneratorSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$sub_nonrefs {
	jint	keysize;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_KeyPairGeneratorSpi$sub_nonrefs	java_security_KeyPairGeneratorSpi;
    _jc_gnu_java_security_provider_DSAKeyPairGenerator$sub_nonrefs	gnu_java_security_provider_DSAKeyPairGenerator;
};

// Object instance structure
struct _jc_gnu_java_security_provider_DSAKeyPairGenerator$object {
	_jc_gnu_java_security_provider_DSAKeyPairGenerator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_provider_DSAKeyPairGenerator$vtype	*vtype;
	_jc_gnu_java_security_provider_DSAKeyPairGenerator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_provider_DSAKeyPairGenerator$vtype _jc_gnu_java_security_provider_DSAKeyPairGenerator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_provider_DSAKeyPairGenerator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_provider_DSAKeyPairGenerator$class_object;

#endif	/* _JC_gnu_java_security_provider_DSAKeyPairGenerator_H_ */
